@@ -92,6 +92,8 @@ class Agent(Insight, Channel, Catalog, Dataset):
     def Dataset(self, dataset_slug):
         return Dataset(self._env, self._token, self._agentId, dataset_slug)
 
+
+
     def switch_agent(self):
 
         data = {
@@ -985,6 +987,21 @@ class Askdata(SignUp):
         r = requests.post(url=dataset_url, headers=headers)
         r.raise_for_status()
 
+    def delete_agent(self, agent_slug):
+        agent = self.agents_dataframe()[self.agents_dataframe()['slug'] == agent_slug.lower()]
+        url = self.base_url + "/smartbot/agents/"+ agent.iloc[0]['id']
+        s = requests.Session()
+        s.keep_alive = False
+        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
+        s.mount('https://', HTTPAdapter(max_retries=retries))
+
+        headers = {
+            "Content-Type": "application/json",
+            "Authorization": "Bearer" + " " + self._token
+        }
+
+        r = s.delete(url=url, headers=headers)
+        r.raise_for_status()
 
     def join(self, df:pd.DataFrame, with_query:str, workspace:str, how="inner", on=None, left_on=None, right_on=None, lang="en"):
 
@@ -1203,7 +1220,6 @@ class Askdata(SignUp):
                 logging.error("{}".format(e.__str__()))
                 logging.error("{} workspace not found".format(workspace))
                 return None
-
         else:
             # Get agent_id and dataset_id
             try:
